==> jc-1.4.0.tar.gz: soot/baf/toolkits/base/PeepholeOptimizer.h <==
// public class soot.baf.toolkits.base.PeepholeOptimizer

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class a76a7734eb62f430 soot_BodyTransformer
// @dep_class de5fa3182955e270 soot_Transformer
// @dep_class d118f385c7b8f5ae soot_baf_toolkits_base_PeepholeOptimizer

// header file dependencies
// @dep_header soot_BodyTransformer

#include "soot/BodyTransformer.h"

#ifndef _JC_soot_baf_toolkits_base_PeepholeOptimizer_H_
#define _JC_soot_baf_toolkits_base_PeepholeOptimizer_H_

// Forward structure declarations
struct _jc_java_io_InputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Map$object;
struct _jc_soot_Body$object;
struct _jc_soot_Singletons__24Global$object;
struct _jc_soot_baf_toolkits_base_PeepholeOptimizer$object;

// Typedefs
typedef struct _jc_soot_baf_toolkits_base_PeepholeOptimizer$sub_refs	_jc_soot_baf_toolkits_base_PeepholeOptimizer$sub_refs;
typedef struct _jc_soot_baf_toolkits_base_PeepholeOptimizer$sub_nonrefs	_jc_soot_baf_toolkits_base_PeepholeOptimizer$sub_nonrefs;
typedef struct _jc_soot_baf_toolkits_base_PeepholeOptimizer$refs	_jc_soot_baf_toolkits_base_PeepholeOptimizer$refs;
typedef struct _jc_soot_baf_toolkits_base_PeepholeOptimizer$nonrefs	_jc_soot_baf_toolkits_base_PeepholeOptimizer$nonrefs;
typedef struct _jc_soot_baf_toolkits_base_PeepholeOptimizer$object	_jc_soot_baf_toolkits_base_PeepholeOptimizer$object;

typedef struct _jc_soot_baf_toolkits_base_PeepholeOptimizer$fields_struct	_jc_soot_baf_toolkits_base_PeepholeOptimizer$fields_struct;
typedef const struct _jc_soot_baf_toolkits_base_PeepholeOptimizer$vmethods	_jc_soot_baf_toolkits_base_PeepholeOptimizer$vmethods;
typedef const struct _jc_soot_baf_toolkits_base_PeepholeOptimizer$vtable	_jc_soot_baf_toolkits_base_PeepholeOptimizer$vtable;
typedef const struct _jc_soot_baf_toolkits_base_PeepholeOptimizer$vtype	_jc_soot_baf_toolkits_base_PeepholeOptimizer$vtype;

// Class fields structure
struct _jc_soot_baf_toolkits_base_PeepholeOptimizer$fields_struct {
	struct _jc_java_lang_Class$object	*class__24soot__24baf__24toolkits__24base__24PeepholeOptimizer;
};
extern _jc_soot_baf_toolkits_base_PeepholeOptimizer$fields_struct _jc_soot_baf_toolkits_base_PeepholeOptimizer$class_fields;

// Constructors
extern void _jc_soot_baf_toolkits_base_PeepholeOptimizer$method$_init$bbe94f634b20986f(_jc_env *, struct _jc_soot_baf_toolkits_base_PeepholeOptimizer$object *, struct _jc_soot_Singletons__24Global$object *);

// Virtual methods
extern void _jc_soot_baf_toolkits_base_PeepholeOptimizer$method$internalTransform$9abd4924859b68a3(_jc_env *, struct _jc_soot_baf_toolkits_base_PeepholeOptimizer$object *, struct _jc_soot_Body$object *, struct _jc_java_lang_String$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_soot_baf_toolkits_base_PeepholeOptimizer$method_info$internalTransform$9abd4924859b68a3;

// Static methods
extern struct _jc_java_lang_Class$object *_jc_soot_baf_toolkits_base_PeepholeOptimizer$method$class__24$57cd45dca0be1678(_jc_env *, struct _jc_java_lang_String$object *);
extern struct _jc_soot_baf_toolkits_base_PeepholeOptimizer$object *_jc_soot_baf_toolkits_base_PeepholeOptimizer$method$v$6f7c30e5dacfebdd(_jc_env *);

// Virtual methods structure
struct _jc_soot_baf_toolkits_base_PeepholeOptimizer$vmethods {
	void	(*internalTransform$9abd4924859b68a3)(_jc_env *, struct _jc_soot_baf_toolkits_base_PeepholeOptimizer$object *, struct _jc_soot_Body$object *, struct _jc_java_lang_String$object *, struct _jc_object *);
};

// Vtable
struct _jc_soot_baf_toolkits_base_PeepholeOptimizer$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_Transformer$vmethods	soot_Transformer;
	_jc_soot_BodyTransformer$vmethods	soot_BodyTransformer;
	_jc_soot_baf_toolkits_base_PeepholeOptimizer$vmethods	soot_baf_toolkits_base_PeepholeOptimizer;
};

// Vtype
struct _jc_soot_baf_toolkits_base_PeepholeOptimizer$vtype {
	_jc_type			type;
	_jc_soot_baf_toolkits_base_PeepholeOptimizer$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_baf_toolkits_base_PeepholeOptimizer$sub_refs {
	struct _jc_java_io_InputStream$object	*peepholeListingStream;
	struct _jc_java_lang_String$object	*packageName;
	struct _jc_object	*peepholeMap;
};

// Reference instance fields (object)
struct _jc_soot_baf_toolkits_base_PeepholeOptimizer$refs {
    _jc_soot_baf_toolkits_base_PeepholeOptimizer$sub_refs	soot_baf_toolkits_base_PeepholeOptimizer;
    _jc_soot_BodyTransformer$sub_refs	soot_BodyTransformer;
    _jc_soot_Transformer$sub_refs	soot_Transformer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_baf_toolkits_base_PeepholeOptimizer$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_baf_toolkits_base_PeepholeOptimizer$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_Transformer$sub_nonrefs	soot_Transformer;
    _jc_soot_BodyTransformer$sub_nonrefs	soot_BodyTransformer;
    _jc_soot_baf_toolkits_base_PeepholeOptimizer$sub_nonrefs	soot_baf_toolkits_base_PeepholeOptimizer;
};

// Object instance structure
struct _jc_soot_baf_toolkits_base_PeepholeOptimizer$object {
	_jc_soot_baf_toolkits_base_PeepholeOptimizer$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_baf_toolkits_base_PeepholeOptimizer$vtype	*vtype;
	_jc_soot_baf_toolkits_base_PeepholeOptimizer$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_baf_toolkits_base_PeepholeOptimizer$vtype _jc_soot_baf_toolkits_base_PeepholeOptimizer$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_baf_toolkits_base_PeepholeOptimizer, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_baf_toolkits_base_PeepholeOptimizer$class_object;

#endif	/* _JC_soot_baf_toolkits_base_PeepholeOptimizer_H_ */

==> jc-1.4.6.tar.gz: soot/baf/toolkits/base/PeepholeOptimizer.h <==
// public class soot.baf.toolkits.base.PeepholeOptimizer

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class a76a7734eb62f430 soot_BodyTransformer
// @dep_class de5fa3182955e270 soot_Transformer
// @dep_class d118f385c7b8f5ae soot_baf_toolkits_base_PeepholeOptimizer

// header file dependencies
// @dep_header soot_BodyTransformer

#include "soot/BodyTransformer.h"

#ifndef _JC_soot_baf_toolkits_base_PeepholeOptimizer_H_
#define _JC_soot_baf_toolkits_base_PeepholeOptimizer_H_

// Forward structure declarations
struct _jc_java_io_InputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Map$object;
struct _jc_soot_Body$object;
struct _jc_soot_Singletons__24Global$object;
struct _jc_soot_baf_toolkits_base_PeepholeOptimizer$object;

// Typedefs
typedef struct _jc_soot_baf_toolkits_base_PeepholeOptimizer$sub_refs	_jc_soot_baf_toolkits_base_PeepholeOptimizer$sub_refs;
typedef struct _jc_soot_baf_toolkits_base_PeepholeOptimizer$sub_nonrefs	_jc_soot_baf_toolkits_base_PeepholeOptimizer$sub_nonrefs;
typedef struct _jc_soot_baf_toolkits_base_PeepholeOptimizer$refs	_jc_soot_baf_toolkits_base_PeepholeOptimizer$refs;
typedef struct _jc_soot_baf_toolkits_base_PeepholeOptimizer$nonrefs	_jc_soot_baf_toolkits_base_PeepholeOptimizer$nonrefs;
typedef struct _jc_soot_baf_toolkits_base_PeepholeOptimizer$object	_jc_soot_baf_toolkits_base_PeepholeOptimizer$object;

typedef struct _jc_soot_baf_toolkits_base_PeepholeOptimizer$fields_struct	_jc_soot_baf_toolkits_base_PeepholeOptimizer$fields_struct;
typedef const struct _jc_soot_baf_toolkits_base_PeepholeOptimizer$vmethods	_jc_soot_baf_toolkits_base_PeepholeOptimizer$vmethods;
typedef const struct _jc_soot_baf_toolkits_base_PeepholeOptimizer$vtable	_jc_soot_baf_toolkits_base_PeepholeOptimizer$vtable;
typedef const struct _jc_soot_baf_toolkits_base_PeepholeOptimizer$vtype	_jc_soot_baf_toolkits_base_PeepholeOptimizer$vtype;

// Class fields structure
struct _jc_soot_baf_toolkits_base_PeepholeOptimizer$fields_struct {
	struct _jc_java_lang_Class$object	*class__24soot__24baf__24toolkits__24base__24PeepholeOptimizer;
};
extern _jc_soot_baf_toolkits_base_PeepholeOptimizer$fields_struct _jc_soot_baf_toolkits_base_PeepholeOptimizer$class_fields;

// Constructors
extern void _jc_soot_baf_toolkits_base_PeepholeOptimizer$method$_init$bbe94f634b20986f(_jc_env *, struct _jc_soot_baf_toolkits_base_PeepholeOptimizer$object *, struct _jc_soot_Singletons__24Global$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_baf_toolkits_base_PeepholeOptimizer$method$internalTransform$9abd4924859b68a3(_jc_env *, struct _jc_soot_baf_toolkits_base_PeepholeOptimizer$object *, struct _jc_soot_Body$object *, struct _jc_java_lang_String$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_baf_toolkits_base_PeepholeOptimizer$method_info$internalTransform$9abd4924859b68a3;

// Static methods
extern struct _jc_java_lang_Class$object *_jc_soot_baf_toolkits_base_PeepholeOptimizer$method$class__24$57cd45dca0be1678(_jc_env *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_baf_toolkits_base_PeepholeOptimizer$object *_jc_soot_baf_toolkits_base_PeepholeOptimizer$method$v$6f7c30e5dacfebdd(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_baf_toolkits_base_PeepholeOptimizer$vmethods {
	void	(*internalTransform$9abd4924859b68a3)(_jc_env *, struct _jc_soot_baf_toolkits_base_PeepholeOptimizer$object *, struct _jc_soot_Body$object *, struct _jc_java_lang_String$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_baf_toolkits_base_PeepholeOptimizer$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_Transformer$vmethods	soot_Transformer;
	_jc_soot_BodyTransformer$vmethods	soot_BodyTransformer;
	_jc_soot_baf_toolkits_base_PeepholeOptimizer$vmethods	soot_baf_toolkits_base_PeepholeOptimizer;
};

// Vtype
struct _jc_soot_baf_toolkits_base_PeepholeOptimizer$vtype {
	_jc_type			type;
	_jc_soot_baf_toolkits_base_PeepholeOptimizer$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_baf_toolkits_base_PeepholeOptimizer$sub_refs {
	struct _jc_java_io_InputStream$object	*peepholeListingStream;
	struct _jc_java_lang_String$object	*packageName;
	struct _jc_object	*peepholeMap;
};

// Reference instance fields (object)
struct _jc_soot_baf_toolkits_base_PeepholeOptimizer$refs {
    _jc_soot_baf_toolkits_base_PeepholeOptimizer$sub_refs	soot_baf_toolkits_base_PeepholeOptimizer;
    _jc_soot_BodyTransformer$sub_refs	soot_BodyTransformer;
    _jc_soot_Transformer$sub_refs	soot_Transformer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_baf_toolkits_base_PeepholeOptimizer$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_baf_toolkits_base_PeepholeOptimizer$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_Transformer$sub_nonrefs	soot_Transformer;
    _jc_soot_BodyTransformer$sub_nonrefs	soot_BodyTransformer;
    _jc_soot_baf_toolkits_base_PeepholeOptimizer$sub_nonrefs	soot_baf_toolkits_base_PeepholeOptimizer;
};

// Object instance structure
struct _jc_soot_baf_toolkits_base_PeepholeOptimizer$object {
	_jc_soot_baf_toolkits_base_PeepholeOptimizer$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_baf_toolkits_base_PeepholeOptimizer$vtype	*vtype;
	_jc_soot_baf_toolkits_base_PeepholeOptimizer$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_baf_toolkits_base_PeepholeOptimizer$vtype _jc_soot_baf_toolkits_base_PeepholeOptimizer$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_baf_toolkits_base_PeepholeOptimizer, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_baf_toolkits_base_PeepholeOptimizer$class_object;

#endif	/* _JC_soot_baf_toolkits_base_PeepholeOptimizer_H_ */
